% Simuations for Jep review

close all

%% import sequence
formatSpec = '%f%f%[^\n\r]';
filename = 'MrX.seq';
delimiter = ',';
fileID = fopen(filename,'r');

dataArray = textscan(fileID, formatSpec, 'Delimiter', delimiter, 'TextType', 'string',  'ReturnOnError', false);

fclose(fileID);
% Create output variable
sequ = [dataArray{1}];
phase = dataArray{2};
startPhase2= find(phase==2,1,'first');
clearvars filename delimiter formatSpec fileID dataArray ans;


design={'A-p1u0'; 'B-p2u0'; 'X-p0u1'; ...
        'X-p0u2'; 'AX-p1u1'; 'AX-p1u2'; 'BX-p2u1'; 'BX-p2u2';...
        'EY-p1u2'; 'FY-p2u1';'GY-p1u1'; 'HY-p2u2';'context'};


%% import testactivation
files=dir('*testactivation.txt');
hP1=figure('Name','activation Phase 1');
hP2=figure('Name','activation Phase 2');
for ii=1:6
    % Initialize variables.
    filename = files(ii).name;
    
    % Format for each line of text:
    formatSpec = '%f%f%f%f%f%f%f%f%f%f%f%f%f%f%[^\n\r]';
    
    %Open the text file.
    fileID = fopen(filename,'r');
    dataArray = textscan(fileID, formatSpec);
    % Close the text file.
    fclose(fileID);
    
    %Create output variable
    testactivation(:,:,ii)= [dataArray{1:end-1}]; %#ok<*SAGROW>
    
    %plot Phase 1 outcome predction
    figure(hP1)
    subplot(2,3,ii)
    plot(testactivation(1:startPhase2-1,unique(sequ(1:startPhase2-1)),ii))
    title(filename, 'Interpreter', 'none')
    legend('A-p1u0', 'B-p2u0', 'X-p0u1', 'X-p0u2', 'AX-p1u1', 'AX-p1u2', 'BX-p2u1', 'BX-p2u2', 'context')
    
    
    %plot Phase 2 outcome predction
    figure(hP2)
    subplot(2,3,ii)
    plot(testactivation(startPhase2:end,unique(sequ(startPhase2:end)),ii))
    title(filename, 'Interpreter', 'none')
    legend('EY-p1u2', 'FY-p2u1', 'GY-p1u1', 'HY-p2u2', 'context')
    
    
end
clearvars dataArray formatSpec fileID filename

%% calculate associative prediction of each outcome at the beginning of each trial
% by the cues present in this trial

for tt=1:length(sequ)
    outcomepredictions(tt,:)=testactivation(tt,sequ(tt),:);
end
 outcomepredictions=squeeze(outcomepredictions);
   
hConPred=figure('Name','Outcome prediction');
annotation('textbox',[0 0 1 1],'String',design,'FitBoxToText','on');

for tt=1:4
    subplot(2,2,tt)
    trialtype=8+tt;
    plot1=plot(outcomepredictions(sequ==trialtype,:));
    legend('p0','p1', 'p2','u0','u1', 'u2')
    title(['outcome predction for ' design{trialtype}])
    ylabel('associative prediction')
    xlabel('trials')
    set(plot1(1),'DisplayName','p0','Marker','o',...
        'Color',[0 .8 0], 'LineStyle', '-');
    set(plot1(2),'DisplayName','p1','Marker','>',...
        'Color',[0 .8 0], 'LineStyle', '-');
    set(plot1(3),'DisplayName','p2','Marker','<',...
        'Color',[0 .8 0], 'LineStyle', '-');
    set(plot1(4),'DisplayName','u0','Marker','o','Color',[0 0 1], 'LineStyle', '-');
    set(plot1(5),'DisplayName','u1','Marker','>','Color',[0 0 1], 'LineStyle', '-');
    set(plot1(6),'DisplayName','u2','Marker','<','Color',[0 0 1], 'LineStyle', '-');

end


%% read in and plot associative weights
files=dir('*weights.txt');
hW1=figure('Name','weights Phase 1');
hW2=figure('Name','weights Phase 2');
for ii=1:6 % for each outcome
    % Initialize variables.
    filename = files(ii).name;
    
    % Format for each line of text:
    formatSpec = '%f%f%f%f%f%f%f%f%f%[^\n\r]';
    
    %Open the text file.
    fileID = fopen(filename,'r');
    dataArray = textscan(fileID, formatSpec);
    % Close the text file.
    fclose(fileID);
    
    %Create output variable
    weights(:,:,ii)= [dataArray{1:end-1}];
    
    %plot Phase 1 associative weights
    figure(hW1)
    subplot(2,3,ii)
    plot(weights(1:startPhase2-1,1:4,ii))
  
    title(filename, 'Interpreter', 'none')
    legend('Context', 'A', 'B', 'X')
    annotation('textbox',[0 0 1 1],'String',{'A-p1u0'; 'B-p2u0'; 'X-p0u1'; ...
        'X-p0u2'; 'AX-p1u1'; 'AX-p1u2'; 'BX-p2u1'; 'BX-p2u2'},'FitBoxToText','on');
    
    %plot Phase 2 associative weights
    figure(hW2)
    subplot(2,3,ii)
    plot(weights(startPhase2:end,[1 5:9],ii))
    title(filename, 'Interpreter', 'none')
    legend('Context', 'E', 'F', 'G', 'H', 'Y')
        annotation('textbox',[0 0 1 1],'String',{'EY-p1u2'; 'FY-p2u1';...
            'GY-p1u1'; 'HY-p2u2'}, 'FitBoxToText','on');

    
end
clearvars dataArray formatSpec fileID filename
%% plot assocaitie weights for 


hW3=figure('Name','weights Phase 1 per cue');
hW4=figure('Name','weights Phase 2 per cue');
cues={'Context', 'A', 'B', 'X', 'E', 'F', 'G', 'H', 'Y'};
for ii=1:9 % for each cue
    % plot Phase 1 associative weights
    figure(hW3)
    subplot(3,3,ii)
    plot(squeeze(weights(1:8:startPhase2-1,ii,:)))
  
    title(cues(ii), 'Interpreter', 'none')
    legend('p0','p1', 'p2','u0','u1', 'u2')
    annotation('textbox',[0 0 1 1],'String',{'A-p1u0'; 'B-p2u0'; 'X-p0u1'; ...
        'X-p0u2'; 'AX-p1u1'; 'AX-p1u2'; 'BX-p2u1'; 'BX-p2u2'},'FitBoxToText','on');
    
    %plot Phase 2 associative weights
    figure(hW4)
    subplot(3,3,ii)
    plot(squeeze(weights(startPhase2:4:end,ii,:)))
    title(cues(ii), 'Interpreter', 'none')
    legend('p0','p1', 'p2','u0','u1', 'u2')
        annotation('textbox',[0 0 1 1],'String',{'EY-p1u2'; 'FY-p2u1';...
            'GY-p1u1'; 'HY-p2u2'}, 'FitBoxToText','on');
end